
Templates
###########
    
These templates are used to configure Cromwell / CWLTool broadly. For more information, visit `Configuring Janis <https://janis.readthedocs.io/en/latest/references/configuration.html#cromwell>`__.




List of templates for ``janis-assistant``:

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   local
   molpath
   pawsey
   pbs_singularity
   pmac
   singularity
   slurm_singularity
   spartan
   wehi

*This page was auto-generated on 22/12/2020. Please do not directly alter the contents of this page.*
